#  -*- coding: utf-8 -*-
import os
import sys
import time
import gtk
import signal
import hashlib
import threading

__name__	    = 'ChkHash'
__description__ = 'Check MD5/SHA1/SHA256 Hash'
__author__      = 'trhura@gmail.com' 
__has_options__ = True

MD5, SHA1, SHA256 = xrange (3)

selected_file = None
chksum_combo  = None
chksum_entry  = None
info_image    = None
info_label    = None

def is_applicable (selected_files):
    # applicable, if only one file is selected
    global selected_file
    
    if len (selected_files) == 1:
        selected_file = selected_files[0]
        return not os.path.isdir (selected_file)
        
    return False

def prepare_options (builder): 
    global chksum_combo, chksum_entry, info_image, info_label
        
    chksum_combo  = builder.get_object ('checksum-type')
    chksum_entry  = builder.get_object ('checksum')
    chksum_button = builder.get_object ('checksum-button')
    info_image    = builder.get_object ('info-image')
    info_label    = builder.get_object ('info-label')
    copy_button   = builder.get_object ('copy-button')
    
    chksum_combo.get_child (). set_editable (False)
    
    chksum_combo.connect ('changed', on_chksum_combo_change)
    chksum_button.connect ('clicked', on_chksum_button_click)
    copy_button.connect ('clicked', on_copy_button_click)
    
def run (builder, files):
    # No need to do anyth .
    sys.exit (0)

def on_chksum_combo_change (combobox):
    global info_image, info_label
    type = combobox.get_active ()

    if type == MD5:
        checksum = hashlib.md5 ()
    elif type == SHA1:
        checksum = hashlib.sha1 ()
    elif type == SHA256:
        checksum = hashlib.sha256 ()

    update_info (gtk.STOCK_REFRESH, "<small><b>Checking checksum ...</b> (This may take some time)</small>")

    while gtk.events_pending(): # Foce pending ui 
        gtk.main_iteration(False)

    with open (selected_file, 'rb') as file:
        data = True
        while (data):
            data = file.read (checksum.block_size * 1024)
            checksum.update (data)
    
    update_info (gtk.STOCK_INFO,"<small>Click <b>'Compare'</b> to compare with clipboard text.</small>")
    chksum_entry.set_text (checksum.hexdigest ()) 
    
def on_chksum_button_click (combo_button):
    global chksum_entry, info_image, info_label
    chksum =  chksum_entry.get_text ()

    if chksum == '':
        on_chksum_combo_change (chksum_combo)
        chksum =  chksum_entry.get_text ()
        
    clipboard = gtk.clipboard_get ()
    text      = clipboard.wait_for_text ()

    if chksum == text:
        update_info (gtk.STOCK_OK ,"<b>Match</b>")
    else:
        update_info (gtk.STOCK_DIALOG_ERROR, "<b>No match</b>") 


def update_info (stock_image, markup):
    info_image.set_from_stock (stock_image, gtk.ICON_SIZE_LARGE_TOOLBAR)
    info_label.set_markup (markup) 

def on_copy_button_click (button):
    global chksum_entry, info_image, info_label
    chksum =  chksum_entry.get_text ()

    if chksum == '':
        on_chksum_combo_change (chksum_combo)
        chksum =  chksum_entry.get_text ()

    clipboard = gtk.clipboard_get ()
    clipboard.set_text (chksum)

    update_info (gtk.STOCK_OK ,"<small><b>Checksum copied to clipboard.</b></small>") 
