#  -*- coding: utf-8 -*-
import os
import subprocess

__name__	    = 'ConvResizImg'
__description__ = 'Convert & Resize Images'
__author__      = 'trhura@gmail.com'
__has_options__ = True

PIXEL, PERCENT, PRESERVE = xrange (3)

def is_applicable (selected_files):
    # TODO: check if the system has 'convert'
    return True 

def prepare_options (builder):
    width_combo  = builder.get_object ('width-combo')
    height_combo = builder.get_object ('height-combo')
    convert_to   = builder.get_object ('convert-to')
    width_spin   = builder.get_object ('width-spinbutton')
    height_spin  = builder.get_object ('height-spinbutton')
    convert_btn  = builder.get_object ('convert-to-checkbutton')
    
    convert_to.get_child ().set_editable (False)
    width_combo.get_child ().set_editable (False)
    height_combo.get_child ().set_editable (False)

    width_spin.set_value (100)
    height_spin.set_value (100)
    
    width_combo.connect ('changed', on_combo_change, width_spin)
    height_combo.connect ('changed', on_combo_change, height_spin)
    convert_btn.connect ('toggled', on_convert_to_toggle, convert_to)
    
def run (builder, files):
    width       = int (builder.get_object ('width-spinbutton').get_value ())
    height      = int (builder.get_object ('height-spinbutton').get_value ())
    
    width_metric  = builder.get_object ('width-combo').get_active ()
    height_metric = builder.get_object ('height-combo').get_active ()
    aspect_ratio  = builder.get_object ('aspect-ratio-checkbutton').get_active ()

    convert_to    = builder.get_object ('convert-to').get_active_text ()
    convert_to_p  = builder.get_object ('convert-to-checkbutton').get_active () 
    
    if width_metric == PIXEL:           # pixel
        width_string = str (width)
    elif width_metric == PERCENT:       # percent
        width_string = str (width) + '%'
    else:                               # preserved
        width_string = '' 

    if height_metric == PIXEL:          # pixel
        height_string = str (height)
    elif height_metric == PERCENT:      # percent
        height_string = str (height) + '%'
    else:                               # preserved
        height_string = ''
        
    if height_metric  == PRESERVE:      # if height is preserved
        geometry_string = width_string 
    elif aspect_ratio:
        geometry_string = width_string + 'x' + height_string + '^'
    else:
        geometry_string = width_string + 'x' + height_string + '!'

    message = ''
    success = True
    
    for file in files:
        print geometry_string

        name, ext = os.path.splitext (os.path.basename(file))

        if convert_to_p:
            ext = '.' + convert_to

        outfile = os.path.join (os.path.dirname (file), name + '_meek' + ext)
        args    = ['convert', file, '-resize', geometry_string, outfile]

        process =  subprocess.Popen (args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
        process.wait ()

        if process.returncode == 0:
            message += "Successfully converted/resized %s\n" %file
        else:
            message += "Failed to convert/resize %s\n" %file
            success = False

        message += process.stdout.read () 
        process.stdout.close ()
        message += '\n'
        
    return (success, message)

def on_combo_change (combobox, spinbutton):
    if combobox.get_active () == PRESERVE:
        spinbutton.set_property ('sensitive', False)
    else:
        spinbutton.set_property ('sensitive', True)

def on_convert_to_toggle (button, comboentry):
    if button.get_active ():
        comboentry.set_property ('sensitive', True)
    else:
        comboentry.set_property ('sensitive', False) 
